@@ -11,27 +11,32 @@ import {
     Settings,
     Sparkles,
 } from "lucide-solid";
-import { For, Show, createSignal } from "solid-js";
+import { For, Show, createResource, createSignal } from "solid-js";
 import { render } from "solid-js/web";
 import { Motion } from "solid-motionone";
 
-const Welcome = ({ onNext }: { onNext: () => void }) => (
+const Welcome = ({ onNext, t }: { onNext: () => void; t: () => Record<string, string> | undefined }) => (
     <Motion.div initial={{ opacity: 0, y: 20 }} animate={{ opacity: 1, y: 0 }} class="text-center">
         <Sparkles class="w-8 h-8 text-purple-400 mx-auto mb-4" />
         <h1 class="text-3xl font-bold text-white mb-4 bg-gradient-to-r from-purple-400 via-white to-purple-400 bg-clip-text text-transparent">
-            Welcome to Legcord
+            {t()?.["setup-welcomeTitle"] ?? "Welcome to Legcord"}
         </h1>
-        <p class="text-gray-400 mb-8">Let's get you set up with your perfect configuration.</p>
+        <p class="text-gray-400 mb-8">
+            {t()?.["setup-welcomeSubtitle"] ?? "Let's get you set up with your perfect configuration."}
+        </p>
         <Motion.button
             onClick={onNext}
             class="px-6 py-2.5 rounded-xl bg-gradient-to-r from-purple-600 to-indigo-600 hover:from-purple-500 hover:to-indigo-500 text-white font-medium"
         >
-            Get Started
+            {t()?.["setup-getStarted"] ?? "Get Started"}
         </Motion.button>
     </Motion.div>
 );
 
-const WindowStyle = ({ readyToNext }: { readyToNext: (valid: boolean) => void }) => {
+const WindowStyle = ({
+    readyToNext,
+    t,
+}: { readyToNext: (valid: boolean) => void; t: () => Record<string, string> | undefined }) => {
     const [selectedStyle, setSelectedStyle] = createSignal<string | null>(null);
 
     const handleStyleSelect = (styleId: string) => {
@@ -48,24 +53,29 @@ const WindowStyle = ({ readyToNext }: { readyToNext: (valid: boolean) => void })
     const styles = [
         {
             id: "native",
-            title: "Native Window",
-            description: "Use your system's default window decorations",
+            titleKey: "setup-windowStyle-nativeTitle",
+            descKey: "setup-windowStyle-nativeDesc",
             screenshot: "legcord://assets/native.png",
         },
         {
             id: "default",
-            title: "Custom Titlebar",
-            description: "Use Legcord's custom titlebar design",
+            titleKey: "setup-windowStyle-customTitle",
+            descKey: "setup-windowStyle-customDesc",
             screenshot: "legcord://assets/custom.png",
         },
     ];
+    const lang = t();
 
     return (
         <div class="space-y-6">
             <div class="text-center">
                 <Monitor class="w-8 h-8 text-purple-400 mx-auto mb-4" />
-                <h2 class="text-2xl font-bold text-white mb-2">Choose Window Style</h2>
-                <p class="text-gray-400">Select how Legcord appears on your machine</p>
+                <h2 class="text-2xl font-bold text-white mb-2">
+                    {lang?.["setup-chooseWindowStyle"] ?? "Choose Window Style"}
+                </h2>
+                <p class="text-gray-400">
+                    {lang?.["setup-selectAppearance"] ?? "Select how Legcord appears on your machine"}
+                </p>
             </div>
 
             <div class="space-y-4">
@@ -83,13 +93,15 @@ const WindowStyle = ({ readyToNext }: { readyToNext: (valid: boolean) => void })
                                 <div class="w-32 h-24 rounded-lg overflow-hidden flex-shrink-0">
                                     <img
                                         src={item.screenshot}
-                                        alt={`${item.title} preview`}
+                                        alt={`${lang?.[item.titleKey] ?? item.titleKey} preview`}
                                         class="w-full h-full object-cover"
                                     />
                                 </div>
                                 <div class="flex-1">
-                                    <h3 class="text-lg font-semibold text-white">{item.title}</h3>
-                                    <p class="text-gray-400 text-sm mt-1">{item.description}</p>
+                                    <h3 class="text-lg font-semibold text-white">
+                                        {lang?.[item.titleKey] ?? item.titleKey}
+                                    </h3>
+                                    <p class="text-gray-400 text-sm mt-1">{lang?.[item.descKey] ?? item.descKey}</p>
                                 </div>
                                 <div
                                     class={`w-5 h-5 rounded-full border-2 transition-colors ${
@@ -109,7 +121,10 @@ const WindowStyle = ({ readyToNext }: { readyToNext: (valid: boolean) => void })
     );
 };
 
-const TraySettings = ({ readyToNext }: { readyToNext: (valid: boolean) => void }) => {
+const TraySettings = ({
+    readyToNext,
+    t,
+}: { readyToNext: (valid: boolean) => void; t: () => Record<string, string> | undefined }) => {
     const [selectedOption, setSelectedOption] = createSignal<string | null>(null);
 
     const handleOptionSelect = (optionId: string) => {
@@ -124,26 +139,19 @@ const TraySettings = ({ readyToNext }: { readyToNext: (valid: boolean) => void }
     };
 
     const options = [
-        {
-            id: "dynamic",
-            title: "Enable Tray Icon",
-            description: "Show Legcord in your system tray",
-            icon: LaptopMinimalCheck,
-        },
-        {
-            id: "disabled",
-            title: "Disable Tray Icon",
-            description: "Don't show Legcord in your system tray",
-            icon: LaptopMinimal,
-        },
+        { id: "dynamic", titleKey: "setup-trayEnableTitle", descKey: "setup-trayEnableDesc", icon: LaptopMinimalCheck },
+        { id: "disabled", titleKey: "setup-trayDisableTitle", descKey: "setup-trayDisableDesc", icon: LaptopMinimal },
     ];
+    const lang = t();
 
     return (
         <div class="space-y-6">
             <div class="text-center">
                 <MinimizeIcon class="w-8 h-8 text-purple-400 mx-auto mb-4" />
-                <h2 class="text-2xl font-bold text-white mb-2">System Tray</h2>
-                <p class="text-gray-400">Choose whether to enable the system tray icon</p>
+                <h2 class="text-2xl font-bold text-white mb-2">{lang?.["setup-systemTray"] ?? "System Tray"}</h2>
+                <p class="text-gray-400">
+                    {lang?.["setup-trayChoose"] ?? "Choose whether to enable the system tray icon"}
+                </p>
             </div>
             <Show when={window.setup.os === "linux"}>
                 <div class="space-y-4">
@@ -151,7 +159,8 @@ const TraySettings = ({ readyToNext }: { readyToNext: (valid: boolean) => void }
                         <CircleAlert class="w-5 h-5 text-yellow-400 flex-shrink-0" />
                         <div>
                             <p class="text-yellow-200/80 text-sm mt-0.5">
-                                System tray functionality may have issues or behave differently on Linux systems.
+                                {lang?.["setup-linuxTrayWarning"] ??
+                                    "System tray functionality may have issues or behave differently on Linux systems."}
                             </p>
                         </div>
                     </div>
@@ -176,8 +185,10 @@ const TraySettings = ({ readyToNext }: { readyToNext: (valid: boolean) => void }
                                 <option.icon class="w-6 h-6 text-purple-400" />
                             </div>
                             <div class="flex-1">
-                                <h3 class="text-lg font-semibold text-white">{option.title}</h3>
-                                <p class="text-gray-400 text-sm mt-1">{option.description}</p>
+                                <h3 class="text-lg font-semibold text-white">
+                                    {lang?.[option.titleKey] ?? option.titleKey}
+                                </h3>
+                                <p class="text-gray-400 text-sm mt-1">{lang?.[option.descKey] ?? option.descKey}</p>
                             </div>
                             <div
                                 class={`w-5 h-5 rounded-full border-2 transition-colors ${
@@ -196,27 +207,34 @@ const TraySettings = ({ readyToNext }: { readyToNext: (valid: boolean) => void }
     );
 };
 
-const Finish = ({ restart }: { restart: () => void }) => (
+const Finish = ({ restart, t }: { restart: () => void; t: () => Record<string, string> | undefined }) => (
     <div class="text-center">
         <Box class="w-8 h-8 text-purple-400 mx-auto mb-4" />
-        <h2 class="text-2xl font-bold text-white mb-4">You're All Set!</h2>
-        <p class="text-gray-400 mb-6">Your Legcord configuration is complete and personalized to your preferences.</p>
+        <h2 class="text-2xl font-bold text-white mb-4">{t()?.["setup-finishTitle"] ?? "You're All Set!"}</h2>
+        <p class="text-gray-400 mb-6">
+            {t()?.["setup-finishSubtitle"] ??
+                "Your Legcord configuration is complete and personalized to your preferences."}
+        </p>
         <div class="p-4 rounded-xl bg-gray-800/40 border border-gray-700/30 mb-6">
             <Settings class="w-6 h-6 text-purple-400 mx-auto mb-2" />
             <p class="text-sm text-gray-400">
-                Need to make changes later? You'll find all these options in Discord's settings menu under Legcord.
+                {t()?.["setup-finishSettingsNote"] ??
+                    "Need to make changes later? You'll find all these options in Discord's settings menu under Legcord."}
             </p>
         </div>
         <Motion.button
             onClick={restart}
             class="px-6 py-2.5 rounded-xl bg-gradient-to-r from-purple-600 to-indigo-600 hover:from-purple-500 hover:to-indigo-500 text-white font-medium"
         >
-            Launch Legcord
+            {t()?.["setup-launchLegcord"] ?? "Launch Legcord"}
         </Motion.button>
     </div>
 );
 
-const ModSelector = ({ readyToNext }: { readyToNext: (valid: boolean) => void }) => {
+const ModSelector = ({
+    readyToNext,
+    t,
+}: { readyToNext: (valid: boolean) => void; t: () => Record<string, string> | undefined }) => {
     const [selectedMod, setSelectedMod] = createSignal<string | null>(null);
     const handleModSelect = (optionId: string) => {
         const newValue = selectedMod() === optionId ? null : optionId;
@@ -235,30 +253,34 @@ const ModSelector = ({ readyToNext }: { readyToNext: (valid: boolean) => void })
     const mods = [
         {
             id: "vencord",
-            title: "Vencord",
-            description: "Client mod with plugins and themes.",
+            titleKey: "setup-vencordTitle",
+            descKey: "setup-vencordDesc",
             icon: "legcord://assets/vencord.png",
         },
         {
             id: "equicord",
-            title: "Equicord",
-            description: "A fork of Vencord with more plugins.",
+            titleKey: "setup-equicordTitle",
+            descKey: "setup-equicordDesc",
             icon: "legcord://assets/equicord.png",
         },
     ];
+    const lang = t();
 
     return (
         <div class="space-y-6">
             <div class="text-center">
                 <PuzzleIcon class="w-8 h-8 text-purple-400 mx-auto mb-4" />
-                <h2 class="text-2xl font-bold text-white mb-2">Choose Your Client Mod</h2>
+                <h2 class="text-2xl font-bold text-white mb-2">
+                    {lang?.["setup-modSelectorTitle"] ?? "Choose Your Client Mod"}
+                </h2>
                 <p class="text-gray-400">
-                    Legcord includes Shelter out of the box, but you can also choose another client mod if wanted.
+                    {lang?.["setup-modSelectorSubtitle"] ??
+                        "Legcord includes Shelter out of the box, but you can also choose another client mod if wanted."}
                 </p>
             </div>
 
             <div class="space-y-3">
-                <For each={mods} fallback={<div>Loading...</div>}>
+                <For each={mods} fallback={<div>{lang?.["setup-loading"] ?? "Loading..."}</div>}>
                     {(mod) => (
                         <Motion.button
                             onClick={() => handleModSelect(mod.id)}
@@ -276,13 +298,15 @@ const ModSelector = ({ readyToNext }: { readyToNext: (valid: boolean) => void })
                                 >
                                     <img
                                         src={mod.icon}
-                                        alt={`${mod.title} icon`}
+                                        alt={`${lang?.[mod.titleKey] ?? mod.titleKey} icon`}
                                         class="w-full h-full object-contain p-1.5"
                                     />
                                 </div>
                                 <div class="flex-1">
-                                    <h3 class="text-lg font-semibold text-white">{mod.title}</h3>
-                                    <p class="text-gray-400 text-sm mt-1">{mod.description}</p>
+                                    <h3 class="text-lg font-semibold text-white">
+                                        {lang?.[mod.titleKey] ?? mod.titleKey}
+                                    </h3>
+                                    <p class="text-gray-400 text-sm mt-1">{lang?.[mod.descKey] ?? mod.descKey}</p>
                                 </div>
                                 <div
                                     class={`w-5 h-5 rounded-full border-2 transition-colors ${
@@ -308,13 +332,14 @@ const ModSelector = ({ readyToNext }: { readyToNext: (valid: boolean) => void })
                   : "border-gray-700/30 text-gray-500 hover:border-purple-500/50 hover:text-purple-400 hover:bg-purple-500/10"
           }`}
             >
-                Use Shelter Only
+                {lang?.["setup-useShelterOnly"] ?? "Use Shelter Only"}
             </Motion.button>
         </div>
     );
 };
 
 function Stepper() {
+    const [t] = createResource(() => window.setup.getRawLang());
     const [currentStep, setCurrentStep] = createSignal(0);
     const [isValid, setValid] = createSignal(true);
     const maxSteps = 5;
@@ -337,6 +362,11 @@ function Stepper() {
         window.setup.saveSettings({ doneSetup: true });
         window.setup.restart();
     };
+    const stepOfText = () => {
+        const lang = t();
+        const template = lang?.["setup-stepOf"] ?? "Step {current} of {total}";
+        return template.replace("{current}", String(currentStep() + 1)).replace("{total}", String(maxSteps));
+    };
     return (
         <div class="min-h-screen flex items-center justify-center">
             <Motion.div
@@ -345,19 +375,19 @@ function Stepper() {
                 class="w-full max-w-md p-8 rounded-3xl bg-gradient-to-br from-[#171631] via-gray-900 to-[#171631] backdrop-blur-xl border border-gray-800/50 shadow-2xl"
             >
                 <Show when={currentStep() === 0}>
-                    <Welcome onNext={handleNext} />
+                    <Welcome onNext={handleNext} t={t} />
                 </Show>
                 <Show when={currentStep() === 1}>
-                    <WindowStyle readyToNext={setReady} />
+                    <WindowStyle readyToNext={setReady} t={t} />
                 </Show>
                 <Show when={currentStep() === 2}>
-                    <ModSelector readyToNext={setReady} />
+                    <ModSelector readyToNext={setReady} t={t} />
                 </Show>
                 <Show when={currentStep() === 3}>
-                    <TraySettings readyToNext={setReady} />
+                    <TraySettings readyToNext={setReady} t={t} />
                 </Show>
                 <Show when={currentStep() === 4}>
-                    <Finish restart={restart} />
+                    <Finish restart={restart} t={t} />
                 </Show>
 
                 <Show when={currentStep() !== 0 && currentStep() !== 4}>
@@ -367,11 +397,11 @@ function Stepper() {
                             class="px-6 py-2.5 rounded-xl bg-gray-800 hover:bg-gray-700 text-white font-medium transition-colors inline-flex items-center gap-2"
                         >
                             <ChevronLeft class="w-4 h-4" />
-                            Back
+                            {t()?.["setup-back"] ?? "Back"}
                         </Motion.button>
 
                         <div class="px-4 py-1 rounded-full bg-gray-800/50 text-gray-400 font-medium text-sm">
-                            Step {currentStep() + 1} of {maxSteps}
+                            {stepOfText()}
                         </div>
 
                         <Motion.button
@@ -382,7 +412,7 @@ function Stepper() {
                                     : "bg-gray-700 cursor-not-allowed opacity-50"
                             }`}
                         >
-                            Next
+                            {t()?.["setup-next"] ?? "Next"}
                             <ChevronRight class="w-4 h-4" />
                         </Motion.button>
                     </div>
