@@ -1,4 +1,4 @@
-import { type JSX, type JSXElement, Show } from "solid-js";
+import { type JSXElement, Show } from "solid-js";
 import { Dropdown } from "./Dropdown.jsx";
 import classes from "./DropdownItem.module.css";
 const {
@@ -10,8 +10,9 @@ export const DropdownItem = (props: {
     note: string;
     link?: string;
     value: string;
-    onChange: JSX.EventHandler<HTMLSelectElement, Event>;
-    children: JSXElement[];
+    onChange: (val: string) => void;
+    options: { label: string; value: string | number }[];
+    limitHeight?: boolean | undefined;
     extraItems?: JSXElement;
 }) => {
     return (
@@ -19,12 +20,18 @@ export const DropdownItem = (props: {
             <Header class={classes.title} tag={HeaderTags.H3}>
                 {props.title}
             </Header>
-            <div class={classes.note}>{props.note}</div>
-            <Show when={props.link} keyed>
-                <LinkButton href={props.link!}>Learn more here.</LinkButton>
-            </Show>
-            {/* biome-ignore lint/correctness/noChildrenProp: FIX-ME, couldn't figure out proper types */}
-            <Dropdown value={props.value} onChange={props.onChange} children={props.children} />
+            <div class={classes.note}>
+                {props.note}
+                <Show when={props.link} keyed>
+                    <LinkButton href={props.link!}> Learn more here.</LinkButton>
+                </Show>
+            </div>
+            <Dropdown
+                value={props.value}
+                onChange={props.onChange}
+                options={props.options}
+                limitHeight={props.limitHeight}
+            />
             <Show when={props.extraItems} keyed>
                 {props.extraItems}
             </Show>
