@@ -1,5 +1,6 @@
 /// <reference path="../../../node_modules/@uwu/shelter-defs/dist/shelter-defs/rootdefs.d.ts" />
 import { KeybindsPage } from "./pages/KeybindsPage.jsx";
+import { RegisteredGamesPage } from "./pages/RegisteredGamesPage.jsx";
 import { SettingsPage } from "./pages/SettingsPage.jsx";
 import { ThemesPage } from "./pages/ThemesPage.jsx";
 
@@ -18,23 +19,23 @@ const settingsPages = [
     registerSection("section", "legcord-settings", "Settings", SettingsPage),
     registerSection("section", "legcord-themes", "Themes", ThemesPage),
     registerSection("section", "legcord-keybinds", "Keybinds", KeybindsPage),
+    registerSection("section", "legcord-games", "Games", RegisteredGamesPage),
 ];
 
 function restartRequired(payload: { event: string; properties: { origin_pane: string } }) {
     if (payload.event === "settings_pane_viewed" && typeof payload.properties.origin_pane !== "undefined") {
-        if (payload.properties.origin_pane === "legcord-settings") {
-            if (isRestartRequired) {
-                openConfirmationModal({
-                    header: () => "Restart required",
-                    body: () => "You need to restart to apply these changes.",
-                    type: "danger",
-                    confirmText: "Restart",
-                    cancelText: "I'll do it later",
-                }).then(
-                    () => window.legcord.restart(),
-                    () => console.log("restart skipped"),
-                );
-            }
+        const pane = payload.properties.origin_pane;
+        if ((pane === "legcord-settings" || pane === "legcord-games") && isRestartRequired) {
+            openConfirmationModal({
+                header: () => store.i18n["settings-restartRequired"],
+                body: () => store.i18n["settings-restartRequiredBody"],
+                type: "danger",
+                confirmText: store.i18n["settings-restart"],
+                cancelText: store.i18n["settings-restartLater"],
+            }).then(
+                () => window.legcord.restart(),
+                () => console.log("restart skipped"),
+            );
         }
     }
 }
