@@ -40,34 +40,28 @@ export function SettingsPage() {
                 Equicord
             </SwitchItem>
             <SwitchItem
-                note={store.i18n["settings-invitewebsocket-desc"]}
-                value={settings.inviteWebsocket}
-                onChange={(e: boolean) => setConfig("inviteWebsocket", e, true)}
+                note={store.i18n["settings-extendedPluginAbilities-desc"]}
+                value={settings.extendedPluginAbilities}
+                onChange={(e: boolean) => setConfig("extendedPluginAbilities", e)}
             >
-                {store.i18n["settings-invitewebsocket"]}
+                {store.i18n["settings-extendedPluginAbilities"]}
             </SwitchItem>
-            <Header class={classes.category} tag={HeaderTags.H5}>
-                {store.i18n["settings-category-lookAndFeel"]}
-            </Header>
             <DropdownItem
                 value={settings.windowStyle}
-                onChange={(e) =>
-                    setConfig("windowStyle", (e.target as HTMLInputElement).value as Settings["windowStyle"], true)
-                }
+                onChange={(v) => setConfig("windowStyle", v as Settings["windowStyle"], true)}
                 title={store.i18n["settings-theme"]}
                 note={store.i18n["settings-theme-desc"]}
                 link="https://github.com/Legcord/Legcord/wiki/Settings-%5Bwip%5D#legcord-theme"
-            >
-                <option value="default">{store.i18n["settings-theme-default"]}</option>
-                <option value="native">{store.i18n["settings-theme-native"]}</option>
-                <option value="overlay">{store.i18n["settings-theme-overlay"]}</option>
-                <option value="legacy">Legacy</option>
-            </DropdownItem>
+                options={[
+                    { label: store.i18n["settings-theme-default"], value: "default" },
+                    { label: store.i18n["settings-theme-native"], value: "native" },
+                    { label: store.i18n["settings-theme-overlay"], value: "overlay" },
+                    { label: store.i18n["settings-theme-legacy"], value: "legacy" },
+                ]}
+            />
             <DropdownItem
                 value={store.settings.transparency}
-                onChange={(e) =>
-                    setConfig("transparency", (e.target as HTMLInputElement).value as Settings["transparency"], true)
-                }
+                onChange={(v) => setConfig("transparency", v as Settings["transparency"], true)}
                 title={store.i18n["settings-transparency"]}
                 note={store.i18n["settings-transparency-desc"]}
                 link="https://github.com/Legcord/Legcord/wiki/Transparency-options"
@@ -91,13 +85,14 @@ export function SettingsPage() {
                         </div>
                     </Show>
                 }
-            >
-                <option value="universal">{store.i18n["settings-transparency-universal"]}</option>
-                <Show when={window.legcord.platform === "win32" || window.legcord.platform === "darwin"}>
-                    <option value="modern">{store.i18n["settings-transparency-modern"]}</option>
-                </Show>
-                <option value="none">{store.i18n["settings-none"]}</option>
-            </DropdownItem>
+                options={[
+                    { label: store.i18n["settings-transparency-universal"], value: "universal" },
+                    ...(window.legcord.platform === "win32" || window.legcord.platform === "darwin"
+                        ? [{ label: store.i18n["settings-transparency-modern"], value: "modern" }]
+                        : []),
+                    { label: store.i18n["settings-none"], value: "none" },
+                ]}
+            />
             <Show when={settings.windowStyle === "native"}>
                 <SwitchItem
                     note={store.i18n["settings-autoHideMenuBar-desc"]}
@@ -118,20 +113,21 @@ export function SettingsPage() {
             </Show>
             <DropdownItem
                 value={settings.tray}
-                onChange={(e) => setConfig("tray", (e.target as HTMLInputElement).value as Settings["tray"], true)}
+                onChange={(v) => setConfig("tray", v as Settings["tray"], true)}
                 title={store.i18n["settings-trayIcon"]}
                 note={store.i18n["settings-trayIcon-desc"]}
-            >
-                <option value="dynamic">{store.i18n["settings-trayIcon-dynamic"]}</option>
-                <option value="disabled">{store.i18n["settings-trayIcon-disabled"]}</option>
-                <option value="dsc-tray">{store.i18n["settings-trayIcon-normal"]}</option>
-                <option value="clsc-dsc-tray">{store.i18n["settings-trayIcon-classic"]}</option>
-                <option value="ac_plug_colored">{store.i18n["settings-trayIcon-colored-plug"]}</option>
-                <option value="ac_white_plug">{store.i18n["settings-trayIcon-white-plug"]}</option>
-                <option value="ac_white_plug_hollow">{store.i18n["settings-trayIcon-white-plug-alt"]}</option>
-                <option value="ac_black_plug">{store.i18n["settings-trayIcon-black-plug"]}</option>
-                <option value="ac_black_plug_hollow">{store.i18n["settings-trayIcon-black-plug-alt"]}</option>
-            </DropdownItem>
+                options={[
+                    { label: store.i18n["settings-trayIcon-dynamic"], value: "dynamic" },
+                    { label: store.i18n["settings-trayIcon-disabled"], value: "disabled" },
+                    { label: store.i18n["settings-trayIcon-normal"], value: "dsc-tray" },
+                    { label: store.i18n["settings-trayIcon-classic"], value: "clsc-dsc-tray" },
+                    { label: store.i18n["settings-trayIcon-colored-plug"], value: "ac_plug_colored" },
+                    { label: store.i18n["settings-trayIcon-white-plug"], value: "ac_white_plug" },
+                    { label: store.i18n["settings-trayIcon-white-plug-alt"], value: "ac_white_plug_hollow" },
+                    { label: store.i18n["settings-trayIcon-black-plug"], value: "ac_black_plug" },
+                    { label: store.i18n["settings-trayIcon-black-plug-alt"], value: "ac_black_plug_hollow" },
+                ]}
+            />
             <SwitchItem
                 note={store.i18n["settings-skipSplash-desc"]}
                 value={settings.skipSplash}
@@ -151,17 +147,16 @@ export function SettingsPage() {
             </Header>
             <DropdownItem
                 value={settings.channel}
-                onChange={(e) =>
-                    setConfig("channel", (e.target as HTMLInputElement).value as Settings["channel"], true)
-                }
+                onChange={(v) => setConfig("channel", v as Settings["channel"], true)}
                 title={store.i18n["settings-channel"]}
                 note={store.i18n["settings-channel-desc"]}
                 link="https://support.discord.com/hc/en-us/articles/360035675191-Discord-Testing-Clients"
-            >
-                <option value="stable">Stable</option>
-                <option value="canary">Canary</option>
-                <option value="ptb">PTB</option>
-            </DropdownItem>
+                options={[
+                    { label: store.i18n["settings-channel-stable"], value: "stable" },
+                    { label: store.i18n["settings-channel-canary"], value: "canary" },
+                    { label: store.i18n["settings-channel-ptb"], value: "ptb" },
+                ]}
+            />
             <SwitchItem
                 note={store.i18n["settings-MultiInstance-desc"]}
                 value={settings.multiInstance}
@@ -235,27 +230,22 @@ export function SettingsPage() {
                 {store.i18n["settings-spellcheck"]}
             </SwitchItem>
             <Header class={classes.category} tag={HeaderTags.H5}>
-                Power Management
+                {store.i18n["settings-category-powerManagement"]}
             </Header>
             <DropdownItem
                 value={settings.performanceMode}
-                onChange={(e) =>
-                    setConfig(
-                        "performanceMode",
-                        (e.target as HTMLInputElement).value as Settings["performanceMode"],
-                        true,
-                    )
-                }
+                onChange={(v) => setConfig("performanceMode", v as Settings["performanceMode"], true)}
                 title={store.i18n["settings-prfmMode"]}
                 note={store.i18n["settings-prfmMode-desc"]}
                 link="https://github.com/Legcord/Legcord/blob/dev/src/common/flags.ts"
-            >
-                <option value="dynamic">{store.i18n["settings-prfmMode-dynamic"]}</option>
-                <option value="performance">{store.i18n["settings-prfmMode-performance"]}</option>
-                <option value="battery">{store.i18n["settings-prfmMode-battery"]}</option>
-                <option value="vaapi">{store.i18n["settings-prfmMode-vaapi"]}</option>
-                <option value="none">{store.i18n["settings-none"]}</option>
-            </DropdownItem>
+                options={[
+                    { label: store.i18n["settings-prfmMode-dynamic"], value: "dynamic" },
+                    { label: store.i18n["settings-prfmMode-performance"], value: "performance" },
+                    { label: store.i18n["settings-prfmMode-battery"], value: "battery" },
+                    { label: store.i18n["settings-prfmMode-vaapi"], value: "vaapi" },
+                    { label: store.i18n["settings-none"], value: "none" },
+                ]}
+            />
             <SwitchItem
                 note={store.i18n["settings-blockPowerSavingInVoiceChat-desc"]}
                 value={settings.blockPowerSavingInVoiceChat}
@@ -270,6 +260,40 @@ export function SettingsPage() {
             >
                 {store.i18n["settings-sleepInBackground"]}
             </SwitchItem>
+            <Header class={classes.category} tag={HeaderTags.H5}>
+                {store.i18n["settings-category-arrpc"]}
+            </Header>
+            <SwitchItem
+                note={store.i18n["settings-invitewebsocket-desc"]}
+                value={settings.inviteWebsocket}
+                onChange={(e: boolean) => setConfig("inviteWebsocket", e, true)}
+            >
+                {store.i18n["settings-invitewebsocket"]}
+            </SwitchItem>
+            <Show when={settings.inviteWebsocket === true}>
+                <SwitchItem
+                    note={store.i18n["settings-processScanning-desc"]}
+                    value={settings.processScanning}
+                    onChange={(e: boolean) => setConfig("processScanning", e, true)}
+                >
+                    {store.i18n["settings-processScanning"]}
+                </SwitchItem>
+                <Show when={window.legcord.platform === "win32"}>
+                    <SwitchItem
+                        note={store.i18n["settings-windowsLegacyScanning-desc"]}
+                        value={settings.windowsLegacyScanning}
+                        onChange={(e: boolean) => setConfig("windowsLegacyScanning", e, true)}
+                    >
+                        {store.i18n["settings-windowsLegacyScanning"]}
+                    </SwitchItem>
+                </Show>
+                <TextBoxItem
+                    title={store.i18n["settings-scanInterval"]}
+                    note={store.i18n["settings-scanInterval-desc"]}
+                    value={Number(settings.scanInterval).toString()}
+                    onInput={(v: string) => setConfig("scanInterval", Number(v))}
+                />
+            </Show>
             <Header class={classes.category} tag={HeaderTags.H5}>
                 {store.i18n["settings-category-debug"]}
             </Header>
@@ -277,7 +301,7 @@ export function SettingsPage() {
                 <SwitchItem
                     note={store.i18n["settings-venmic-deviceSelect-desc"]}
                     value={settings.audio.deviceSelect}
-                    onChange={(e) => {
+                    onChange={(e: boolean) => {
                         const audioSettings = structuredClone({ ...settings.audio });
                         audioSettings.deviceSelect = e;
                         setConfig("audio", audioSettings);
@@ -288,7 +312,7 @@ export function SettingsPage() {
                 <SwitchItem
                     note={store.i18n["settings-venmic-granularSelect-desc"]}
                     value={settings.audio.granularSelect}
-                    onChange={(e) => {
+                    onChange={(e: boolean) => {
                         const audioSettings = structuredClone({ ...settings.audio });
                         audioSettings.granularSelect = e;
                         setConfig("audio", audioSettings);
@@ -299,7 +323,7 @@ export function SettingsPage() {
                 <SwitchItem
                     note={store.i18n["settings-venmic-workaround-desc"]}
                     value={settings.audio.workaround}
-                    onChange={(e) => {
+                    onChange={(e: boolean) => {
                         const audioSettings = structuredClone({ ...settings.audio });
                         audioSettings.workaround = e;
                         setConfig("audio", audioSettings);
@@ -310,7 +334,7 @@ export function SettingsPage() {
                 <SwitchItem
                     note={store.i18n["settings-venmic-ignoreVirtual-desc"]}
                     value={settings.audio.ignoreVirtual}
-                    onChange={(e) => {
+                    onChange={(e: boolean) => {
                         const audioSettings = structuredClone({ ...settings.audio });
                         audioSettings.ignoreVirtual = e;
                         setConfig("audio", audioSettings);
@@ -321,7 +345,7 @@ export function SettingsPage() {
                 <SwitchItem
                     note={store.i18n["settings-venmic-ignoreDevices-desc"]}
                     value={settings.audio.ignoreDevices}
-                    onChange={(e) => {
+                    onChange={(e: boolean) => {
                         const audioSettings = structuredClone({ ...settings.audio });
                         audioSettings.ignoreDevices = e;
                         setConfig("audio", audioSettings);
@@ -332,7 +356,7 @@ export function SettingsPage() {
                 <SwitchItem
                     note={store.i18n["settings-venmic-ignoreInputMedia-desc"]}
                     value={settings.audio.ignoreInputMedia}
-                    onChange={(e) => {
+                    onChange={(e: boolean) => {
                         const audioSettings = structuredClone({ ...settings.audio });
                         audioSettings.ignoreInputMedia = e;
                         setConfig("audio", audioSettings);
@@ -343,7 +367,7 @@ export function SettingsPage() {
                 <SwitchItem
                     note={store.i18n["settings-venmic-onlySpeakers-desc"]}
                     value={settings.audio.onlySpeakers}
-                    onChange={(e) => {
+                    onChange={(e: boolean) => {
                         const audioSettings = structuredClone({ ...settings.audio });
                         audioSettings.onlySpeakers = e;
                         setConfig("audio", audioSettings);
@@ -354,7 +378,7 @@ export function SettingsPage() {
                 <SwitchItem
                     note={store.i18n["settings-venmic-onlyDefaultSpeakers-desc"]}
                     value={settings.audio.onlyDefaultSpeakers}
-                    onChange={(e) => {
+                    onChange={(e: boolean) => {
                         const audioSettings = structuredClone({ ...settings.audio });
                         audioSettings.onlyDefaultSpeakers = e;
                         setConfig("audio", audioSettings);
@@ -365,19 +389,19 @@ export function SettingsPage() {
             </Show>
             <DropdownItem
                 value={settings.audio.loopbackType}
-                onChange={(e) => {
+                onChange={(v) => {
                     const audioSettings = structuredClone({ ...settings.audio });
-                    audioSettings.loopbackType = (e.target as HTMLInputElement)
-                        .value as Settings["audio"]["loopbackType"];
+                    audioSettings.loopbackType = v as Settings["audio"]["loopbackType"];
                     setConfig("audio", audioSettings);
                 }}
                 title={store.i18n["settings-audio"]}
                 note={store.i18n["settings-audio-desc"]}
                 link="https://www.electronjs.org/docs/latest/api/session#sessetdisplaymediarequesthandlerhandler-opts"
-            >
-                <option value="loopback">Loopback</option>
-                <option value="loopbackWithMute">Loopback with mute</option>
-            </DropdownItem>
+                options={[
+                    { label: store.i18n["settings-audio-loopback"], value: "loopback" },
+                    { label: store.i18n["settings-audio-loopbackWithMute"], value: "loopbackWithMute" },
+                ]}
+            />
             <SwitchItem
                 note={store.i18n["settings-hardwareAcceleration-desc"]}
                 value={settings.hardwareAcceleration}
